@@ -1,4 +1,5 @@
 from PIL import Image
+
 from spriter.sprite import Sprite
 from tests import Openned
 import mock
@@ -28,7 +29,7 @@ class TestSprite(unittest.TestCase):
         sprite = Sprite(self.paths)
         css = sprite.get_css()
         self.assertEquals(css,
-                          ".sprite{background:url(\"%s/sprite.png\") 0 0 no-repeat}.sprite.ssad{background-position: 0px 0px}.sprite.shappy{background-position: -64px 0px}" % os.getcwd())
+                          ".sprite{background:url(\"%s/sprite.png\") 0 0 no-repeat;display:inline-block}.sprite.ssad{background-position: 0px 0px;width:64px;height:64px}.sprite.shappy{background-position: -64px 0px;width:64px;height:64px}" % os.getcwd())
 
     def test_do_write_css(self):
         """Tests whether a CSS can be correctly written or not"""
@@ -68,10 +69,11 @@ class TestSprite(unittest.TestCase):
             self.assertEquals(compare.histogram(), sprite.image.histogram())
 
     def test_webp_generation(self):
-        sprite = Sprite(self.paths, sprite_path=os.getcwd() + "/tests/",
-                        image_format="RGBA", image_extension="webp",
-                        sprite_name="sprite.webp")
-        sprite.do_write_image()
+        if  hasattr(Image.core,  "webp_decoder"):
+            sprite = Sprite(self.paths, sprite_path=os.getcwd() + "/tests/",
+                            image_format="RGBA", image_extension="webp",
+                            sprite_name="sprite.webp")
+            sprite.do_write_image()
 
 
     def test_create_css_path(self):
